@@ -6,7 +6,7 @@
 #include <string.h>
 #include <sys/types.h>
 
-#include "lrmi.h"
+#include <libx86.h>
 
 typedef u_int8_t byte;
 typedef u_int32_t uint32;
